@@ -1,4 +1,5 @@
-// Copyright (C) 2009 NICTA
+// Copyright (C) 2010 NICTA and the authors listed below
+// http://nicta.com.au
 // 
 // Authors:
 // - Conrad Sanderson (conradsand at ieee dot org)
@@ -63,18 +64,6 @@ Op<T1, op_type>::Op(const T1& in_m, const typename T1::elem_type in_aux, const u
   {
   arma_extra_debug_sigprint();
   }
-
-
-
-template<typename T1, typename op_type>
-Op<T1, op_type>::Op(const u32 in_aux_u32_a, const u32 in_aux_u32_b, const char junk)
-  : m(m)
-  , aux(aux)
-  , aux_u32_a(in_aux_u32_a)
-  , aux_u32_b(in_aux_u32_b)
-  {
-  arma_extra_debug_sigprint();
-  }
   
 
 
